from ....base_classes import ReferencedDataModel


class MainsterModel(ReferencedDataModel):
    reference = """
@Article{mainster-1970,
  Title                    = {Retinal-Temperature Increases Produced by Intense Light Sources},
  Author                   = {M. A. Mainster and T. J. White and J. H. Tips and P. W. Wilson},
  Journal                  = {Journal of the Optical Society of America},
  Year                     = {1970},
  Number                   = {2},
  Pages                    = {264--270},
  Volume                   = {60},
}
"""

    def __init__(self):
        pass
