from ....base_classes import ReferencedDataModel


class NavarroModel(ReferencedDataModel):
    reference = """
@article{navarro-1985,
  title={Accommodation-dependent model of the human eye with aspherics.},
  author={Rafael Fonolla Navarro and Javier Santamar{\'i}a and Juli{\'a}n Besc{\'o}s},
  journal={Journal of the Optical Society of America. A, Optics and image science},
  year={1985},
  volume={2 8},
  pages={ 1273-81 },
  url={https://api.semanticscholar.org/CorpusID:14921290}
}
"""

    def __init__(self):
        pass
